# Report Plugin

[![fastlane Plugin Badge](https://rawcdn.githack.com/fastlane/fastlane/master/fastlane/assets/plugin-badge.svg)](https://rubygems.org/gems/fastlane-plugin-report)

## Getting Started

This project is a [fastlane](https://github.com/fastlane/fastlane) plugin. To get started with `fastlane-plugin-report`, add it to your project by running:

```bash
fastlane add_plugin report
```

## About report

After an action, like scan for instance, you're able to generate a report file.

This fastlane plugin gives you a way to upload and share your report using Slack.

## Example

See this exemple above:

````ruby
report(
    slack_api_token: 'xxxx-0000000-11111111-222222222-xxxxxxxx333333',
    path: './some/path/report.html',
    path_type: 'text/html',
    file_name: 'report.html'
)
````

Parameter | Description | Mandatory | Environment
--------- | ----------- | --------- | -----------
`slack_api_token` | Token of slack rest api. Need to be generated at https://api.slack.com | true | `REPORT_SLACK_API_TOKEN`
`path` | Relative path to report file (ex. ./reports/20170603140211.html) | true | `REPORT_PATH`
`path_type` | Multipart type of your report file (ex. text/html) | true | `REPORT_PATH_TYPE`
`file_name` | Name of your file (ex. 20170603140211.html) | true | `REPORT_FILE_NAME`
`channels` | Selected channels to upload and post your report (default: #channel) | false | `REPORT_SLACK_CHANNELS`
`title` | Title that will be shown on Slack | false | `REPORT_TITLE`
`message` | Message that will be shown on Slack | false | `REPORT_MESSAGE`
`scan_as_pdf` | File that will be sent to Slack (default: `true` if was a HTML file) | false | `REPORT_SCAN_AS_PDF`

## Run tests for this plugin

To run both the tests, and code style validation, run

```
rake
```

To automatically fix many of the styling issues, use
```
rubocop -a
```

## Issues and Feedback

For any other issues and feedback about this plugin, please submit it to this repository.

**NOTE:** Feel free to give feedback or report some bugs or even contribute with some code.

## Troubleshooting

If you have trouble using plugins, check out the [Plugins Troubleshooting](https://docs.fastlane.tools/plugins/plugins-troubleshooting/) guide.

## Using `fastlane` Plugins

For more information about how the `fastlane` plugin system works, check out the [Plugins documentation](https://docs.fastlane.tools/plugins/create-plugin/).

## About `fastlane`

`fastlane` is the easiest way to automate beta deployments and releases for your iOS and Android apps. To learn more, check out [fastlane.tools](https://fastlane.tools).
